usePaymentCodeAboveToComplete property
No description provided for @usePaymentCodeAboveToComplete.
In en, this message translates to: 'Use the payment code above to complete your payment in the Sedad app, then tap the button below.'
Implementation
@override
String get usePaymentCodeAboveToComplete =>
'استخدم رمز الدفع أعلاه لإكمال الدفع في تطبيق سداد، ثم اضغط على الزر أدناه.';