usePaymentCodeAboveToComplete property

  1. @override
String get usePaymentCodeAboveToComplete
override

No description provided for @usePaymentCodeAboveToComplete.

In en, this message translates to: 'Use the payment code above to complete your payment in the Sedad app, then tap the button below.'

Implementation

@override
String get usePaymentCodeAboveToComplete =>
    'Utilisez le code de paiement ci-dessus pour finaliser votre paiement dans l\'application Sedad, puis appuyez sur le bouton ci-dessous.';