ConfigurationListDataInner class abstract

ConfigurationListDataInner

Properties:

Annotations
  • @BuiltValue.new()

Constructors

ConfigurationListDataInner([void updates(ConfigurationListDataInnerBuilder b)])
factory

Properties

config → JsonObject?
no setter
hashCode int
The hash code for this object.
no setterinherited
id String
no setter
isTestingMode bool
no setter
organizationId String?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(ConfigurationListDataInnerBuilder)) ConfigurationListDataInner
Rebuilds the instance.
inherited
toBuilder() → ConfigurationListDataInnerBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<ConfigurationListDataInner>
no setter