inputBuilder property
Optional function to build a custom input widget for the payment process.
open is the callback to open the payment sheet.
Implementation
final Widget Function(VoidCallback open)? inputBuilder;
Optional function to build a custom input widget for the payment process.
open is the callback to open the payment sheet.
final Widget Function(VoidCallback open)? inputBuilder;