MoosylFlutter class

Convenience class to open the payment flow.

When isFullPage is true, pushes MoosylView as a full page. When isFullPage is false, shows MoosylView as a bottom sheet.

Returns PaymentSuccess when payment completes, or null when the user closes without completing payment (e.g. back press).

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

show(BuildContext context, {required String publishableApiKey, required String transactionId, List<MoosylPaymentSummaryItem>? items, bool isFullPage = true, bool isMasriviInBottomSheet = false, String? masriviPhoneNumber}) Future<bool?>
Opens the payment flow. Returns PaymentSuccess on success, null when closed without payment.