MoosylPaymentMethodRenderData class

Data passed to MoosylPaymentMethodBuilder for each payment method row.

Constructors

MoosylPaymentMethodRenderData({required ConfigurationListDataInner method, required PaymentMethodTypes type, required String title, required bool isSelected, required String? selectedMethodId, required bool isRTL, required VoidCallback onSelect})
Creates render data for a payment method row.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
isRTL bool
Whether the surrounding directionality is RTL.
final
isSelected bool
Whether this method is selected.
final
method ConfigurationListDataInner
Raw method from the Moosyl Dart SDK.
final
onSelect VoidCallback
Selects this method.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedMethodId String?
Currently selected method id, if any.
final
title String
Localized method title.
final
type PaymentMethodTypes
Parsed payment method type.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited