masriviPhoneNumber property
Optional phone number to prefill when the selected method opens Masrivi.
Implementation
final String? masriviPhoneNumber;
Optional phone number to prefill when the selected method opens Masrivi.
final String? masriviPhoneNumber;