masriviPresentation property
How Masrivi should be presented when this picker opens the WebView.
Implementation
final MasriviWebViewPresentation masriviPresentation;
How Masrivi should be presented when this picker opens the WebView.
final MasriviWebViewPresentation masriviPresentation;