MoosylPaymentMethodsLoadingData class

Constructors

MoosylPaymentMethodsLoadingData({required Color primaryColor, required Locale locale, required bool isRTL})
Creates render data for the payment methods loading state.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
isRTL bool
Whether the surrounding directionality is RTL.
final
locale Locale
Active locale from the surrounding localization.
final
primaryColor Color
Accent color used by the default UI.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited