MoosylPaymentSummaryItem class

A summary row shown in the Moosyl payment flow.

Constructors

MoosylPaymentSummaryItem({required String label, required double amount})
Creates a payment summary item.
const

Properties

amount double
Amount for this row in MRU.
final
hashCode int
The hash code for this object.
no setterinherited
label String
Label shown for this row.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited