title method

String title(
  1. BuildContext context
)

Gets the localized title for the payment method type.

Uses LocalizationsHelper to retrieve the appropriate localized string for each payment method.

Implementation

String title(BuildContext context) {
  final localizationsHelper = MoosylLocalization.of(context)!;

  return switch (this) {
    PaymentMethodTypes.masrivi => localizationsHelper.masrivi,
    PaymentMethodTypes.bankily => localizationsHelper.bankily,
    PaymentMethodTypes.sedad => localizationsHelper.sedad,
    PaymentMethodTypes.bimBank => localizationsHelper.bimBank,
    PaymentMethodTypes.amanty => localizationsHelper.amanty,
    PaymentMethodTypes.bCIpay => localizationsHelper.bCIpay,
  };
}