usePaymentCodeAboveToComplete property
String
get
usePaymentCodeAboveToComplete
No description provided for @usePaymentCodeAboveToComplete.
In en, this message translates to: 'Use the payment code above to complete your payment in the Sedad app, then tap the button below.'
Implementation
String get usePaymentCodeAboveToComplete;