Moosyl class
Moosyl provides a widget that handles the payment process. It allows you to customize the payment methods, icons, and success callbacks.
- Inheritance
Constructors
-
Moosyl({Key? key, required String publishableApiKey, required String transactionId, Widget inputBuilder(VoidCallback open)?, FutureOr<
void> onPaymentSuccess(bool isSuccess)?, bool isFullPage = false, bool isMasriviInBottomSheet = false, String? masriviPhoneNumber, double masriviBottomSheetHeight = 0.88}) -
Constructor for Moosyl.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- inputBuilder → Widget Function(VoidCallback open)?
-
Optional function to build a custom input widget for the payment process.
openis the callback to open the payment sheet.final - isFullPage → bool
-
When true, shows as full page. When false, shows as bottom sheet.
final
- isMasriviInBottomSheet → bool
-
When true, Masrivi opens inside bottom-sheet content.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- masriviBottomSheetHeight → double
-
Height factor used when Masrivi is rendered as bottom-sheet content.
final
- masriviPhoneNumber → String?
-
Optional phone number to prefill when the selected method opens Masrivi.
final
-
onPaymentSuccess
→ FutureOr<
void> Function(bool isSuccess)? -
Optional callback to be triggered upon successful payment with
PaymentSuccess.final - publishableApiKey → String
-
The API key required to authenticate the payment process.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- transactionId → String
-
The transaction ID associated with the current payment session.
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → _StatelessHookElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
show(
BuildContext context, {required String publishableApiKey, required String transactionId, FutureOr< void> onPaymentSuccess(bool isSuccess)?, bool isFullPage = false, bool isMasriviInBottomSheet = true, String? masriviPhoneNumber, double masriviBottomSheetHeight = 0.88}) → void -
Displays the
MoosylViewmodal sheet to start the payment process.