MoosylPaymentSummaryItem class
A summary row shown in the Moosyl payment flow.
Constructors
- MoosylPaymentSummaryItem({required String label, required double amount})
-
Creates a payment summary item.
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited